/******************************************************************************
*									      *
*	File:     hctfit.c						      *
*	Author:   Alison Chaiken					      *
*	Created:  Tue Feb 17 15:49:54 EST 1987				      *
*	Contents:  a program which computes the theoretical hc2(T) values     *
*                  and pipes  them to stdout given hc2(0)  and  Tc  in the    *
*                  form 'hctfit <hc2(0)> <Tc> <option>'.  <option> must be    *
*                  either 'l' for  a  linear T-dependence  or 'q'  for   a    *
*                  quadratic T-dependence.                                    *
*									      *
*	$Log:	hctfit.c,v $
 * Revision 1.2  88/09/28  16:51:29  alison
 * Previously could not calculate for temperatures greater than 1.0 K!
 * 
 * Revision 1.1  88/09/06  13:57:30  alison
 * Initial revision
 * 								      *
******************************************************************************/

#include <stdio.h>
#include <math.h>

#define SIZE 100

main(argc, argv)
	int             argc;
	char           *argv[];
{
	
	int             k;
	double          hczero,
	                tsq,
	                tc,
	                t,
	                h,
	                increm;

	hczero = atof(argv[1]);	/* hczero = hc2(0 K) */
	tc = atof(argv[2]);	/* tc = critical temperature */

	if (argc != 4 || (*argv[3] != 'l' && *argv[3] != 'q' && *argv[3] != '2'))
	{
		fprintf(stderr, "Format is: 'hctfit <hc2(0)> <Tc> <option>'\n");
		fprintf(stderr, "Options are 'l' for linear and 'q' for quadratic\nand '2' for a 2fluid model fit.\n");
		exit(0);
	}
	increm = tc / SIZE;
	for (k = 0; k <= SIZE; k++)
	{
		t = k * increm;
		tsq = t * t / (tc * tc);
		if (*argv[3] == 'q')
			h = hczero * (1 - tsq);
		if (*argv[3] == 'l')
			h = hczero * (1 - (t / tc));
		if (*argv[3] == '2')
		{
			h = hczero * (1 - tsq) / (1 + tsq);
		}
		printf("%f\t%f\n", t, h);
	}

}
